#!/bin/bash

# ============LICENSE_START=======================================================
#  Copyright (C) 2019 The Nordix Foundation. All rights reserved.
# ================================================================================
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# SPDX-License-Identifier: Apache-2.0
# ============LICENSE_END=========================================================

set -o nounset
set -o errexit
set -o pipefail

if [[ "$DELETE_STACK" != "true" || "$HW_TYPE" != "cloud" ]]; then
  echo "Info  : Skipping stack delete as it is either not a cloud deployment or slack deletion is disabled!"
  exit 0
fi

# NOTE (fdegir): install openstack clients
sudo /bin/rm -rf /tmp/.engine_venv
virtualenv --python python3 --never-download /tmp/.engine_venv
# NOTE (fdegir): we need to use pip.conf pointing to local packages
[[ "$EXECUTION_MODE" == "offline-deployment" ]] && /bin/cp -f /opt/engine/offline/pip/pip.conf /tmp/.engine_venv
set +u
source /tmp/.engine_venv/bin/activate
set -u
pip install --quiet --upgrade pip
# NOTE (fdegir): we only install what is needed rather than all dependencies
pip install --quiet openstacksdk python-openstackclient python-heatclient

# NOTE (fdegir): delete stack
echo "Info: Deleting stack $HEAT_STACK_NAME and keypair $KEYPAIR_NAME"
echo "-------------------------------------------------------------------------"
source /tmp/openrc && /bin/rm -f /tmp/openrc
openstack stack delete  --wait --yes $HEAT_STACK_NAME
openstack keypair delete $KEYPAIR_NAME
echo "-------------------------------------------------------------------------"
echo "Info: Stack $HEAT_STACK_NAME and keypair $KEYPAIR_NAME have been deleted!"

# vim: set ts=2 sw=2 expandtab:
